@@ -4,14 +4,13 @@ use warnings;
 
 package Dist::Zilla::Plugin::Prereqs::Plugins;
 
-our $VERSION = '1.003002';
+our $VERSION = '1.003003';
 
 # ABSTRACT: Add all Dist::Zilla plugins presently in use as prerequisites.
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 use Moose qw( with has around );
-use Dist::Zilla::Util::ConfigDumper qw( config_dumper );
 use Dist::Zilla::Util;
 use MooseX::Types::Moose qw( HashRef ArrayRef Str );
 use Dist::Zilla::Util::BundleInfo;
@@ -102,8 +101,23 @@ sub _build__exclude_hash {
   my ( $self, ) = @_;
   return { map { ( $_ => 1 ) } @{ $self->exclude } };
 }
+around dump_config => sub {
+  my ( $orig, $self, @args ) = @_;
+  my $config = $self->$orig(@args);
+  my $localconf = $config->{ +__PACKAGE__ } = {};
 
-around 'dump_config' => config_dumper( __PACKAGE__, qw( phase relation exclude ) );
+  $localconf->{phase}    = $self->phase;
+  $localconf->{relation} = $self->relation;
+  $localconf->{exclude}  = $self->exclude;
+
+  $localconf->{ q[$] . __PACKAGE__ . '::VERSION' } = $VERSION
+    unless __PACKAGE__ eq ref $self;
+
+  return $config;
+};
+
+__PACKAGE__->meta->make_immutable;
+no Moose;
 
 sub _register_plugin_prereq {
   my ( $self, $package, $lines ) = @_;
@@ -167,8 +181,6 @@ sub register_prereqs {
   return $self->zilla->prereqs;
 }
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
 
 1;
 
@@ -184,7 +196,7 @@ Dist::Zilla::Plugin::Prereqs::Plugins - Add all Dist::Zilla plugins presently in
 
 =head1 VERSION
 
-version 1.003002
+version 1.003003
 
 =head1 SYNOPSIS
 
@@ -289,7 +301,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2017 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
